
:autogenerated:

krotov.structural_conversions module
====================================

.. currentmodule:: krotov.structural_conversions

.. automodule:: krotov.structural_conversions
    :members: control_onto_interval, discretize, extract_controls, extract_controls_mapping, plug_in_pulse_values, pulse_onto_tlist, pulse_options_dict_to_list
    :undoc-members:
    :show-inheritance:
    :member-order: bysource

    Summary
    -------

    Functions:

    .. autosummary::
        :nosignatures:

        control_onto_interval
        discretize
        extract_controls
        extract_controls_mapping
        plug_in_pulse_values
        pulse_onto_tlist
        pulse_options_dict_to_list





    ``__all__``: :func:`control_onto_interval <krotov.structural_conversions.control_onto_interval>`, :func:`discretize <krotov.structural_conversions.discretize>`, :func:`extract_controls <krotov.structural_conversions.extract_controls>`, :func:`extract_controls_mapping <krotov.structural_conversions.extract_controls_mapping>`, :func:`pulse_onto_tlist <krotov.structural_conversions.pulse_onto_tlist>`, :func:`pulse_options_dict_to_list <krotov.structural_conversions.pulse_options_dict_to_list>`



    Reference
    ---------